(* ==============================================================
// Copyright (c) 1996 by Aaron Castro and VK Thakur. 
// Version 3.0 enhancements by Eric Engler.
*)
unit Dbslocat;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, ExtCtrls, db, DBTables, Buttons;

{************************************************************************}
{structure used to set and retrieve information from the locate dialogbox}
{************************************************************************}
type
   TLocateInfo = record
      LocateField: string;   {The field to search}
      LocateText: string;    {The text with pattern to search for}
      CaseSensitive: boolean;{Is the search case sensitive?}
      ExactMatch: boolean;   {Should we look for an exact match?}
      GotoFirst: boolean;    { No search, just goto first record }
      GotoLast: boolean;     { No search, just goto last record }
      FindNext: boolean;     { Don't start from top of file }
   end;

{************************************************************************}
{Locate Dialog box class}
{************************************************************************}
type
  TDLGLocate = class(TForm)
    GroupBox2: TGroupBox;
    Bevel1: TBevel;
    cbxCaseSensitive: TCheckBox;
    rbExactMatch: TRadioButton;
    rbPatternMatch: TRadioButton;
    FindFirstButton: TButton;
    GoToTopButton: TButton;
    GoToEndButton: TButton;
    FindNextButton: TButton;
    txtSearchString: TEdit;
    Label1: TLabel;
    cbxFields: TComboBox;
    Label2: TLabel;
    procedure FindFirstButtonClick(Sender: TObject);
    procedure bCancelClick(Sender: TObject);
    procedure txtSearchStringChange(Sender: TObject);
    procedure GoToTopButtonClick(Sender: TObject);
    procedure GoToEndButtonClick(Sender: TObject);
    procedure FindNextButtonClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    HelpFile: string;
    procedure SetLocateInfo(Info: TLocateInfo);
    function  GetLocateInfo: TLocateInfo;
    procedure AddLocateField(FieldName: string);
  end;

var
   DLGLocate: TDLGLocate;
   GotoFirst, GotoLast, FindNext: boolean;

implementation

uses DBSearch;

{$R *.DFM}

{ Called from DBsearch.pas AFTER showing dialog box }
function TDLGLocate.GetLocateInfo: TLocateInfo;
begin
   GetLocateInfo.LocateField:=cbxFields.Text;
   GetLocateInfo.LocateText:=txtSearchString.Text;
   GetLocateInfo.ExactMatch:=(rbExactMatch.Checked);
   GetLocateInfo.CaseSensitive:=(cbxCaseSensitive.State=cbChecked);
   GetLocateInfo.GotoFirst:=GotoFirst;
   GetLocateInfo.GotoLast:=GotoLast;
   GetLocateInfo.FindNext:=FindNext;
end;

{ Called from DBsearch.pas BEFORE showing dialog box }
procedure TDLGLocate.SetLocateInfo(Info: TLocateInfo);
begin
  GotoFirst:=False;
  GotoLast:=False;
  FindNext:=False;

  {Fill in Field to search}
  with cbxFields do
  begin
    ItemIndex := 0;
    if (Info.LocateField <> '')then
      { get name of last field we searched for }
      ItemIndex := Items.IndexOf(Info.LocateField);
  end;

  {Fill in locate text}
  TxtSearchString.Text:=Info.LocateText;

  { Exact match desired, or use wildcards? }
  if (Info.ExactMatch) then
    rbExactMatch.Checked:=True
  else
    rbPatternMatch.Checked:=True;

  { Case sensitive desired? }
  if (Info.CaseSensitive) then
    cbxCaseSensitive.State:=cbChecked
  else
    cbxCaseSensitive.State:=cbUnchecked;

  { Enable or disable buttons, as appropriate }
  txtSearchStringChange(self);
end;

{*******************************************************************}
{ AddLocateField(FieldName): Field to be added to searchable
  field list.  It adds fields to the combobox listing fields that
  can be searched. }
{*******************************************************************}
procedure TDLGLocate.AddLocateField(FieldName: string);
begin
    cbxFields.Items.Add(FieldName);
end;

procedure TDLGLocate.FindFirstButtonClick(Sender: TObject);
begin
   ModalResult:=mrOK;
end;

procedure TDLGLocate.bCancelClick(Sender: TObject);
begin
   ModalResult:=mrCancel;
end;

procedure TDLGLocate.txtSearchStringChange(Sender: TObject);
begin
   if(Length(txtSearchString.Text) > 0)then
   begin
      FindFirstButton.Enabled := True;
      FindNextButton.Enabled  := True;
   end
   else
   begin
      FindFirstButton.Enabled := False;
      FindNextButton.Enabled  := False;
   end;
end;

procedure TDLGLocate.GoToTopButtonClick(Sender: TObject);
begin
   GotoFirst:=true;
   ModalResult:=mrOK;
end;

procedure TDLGLocate.GoToEndButtonClick(Sender: TObject);
begin
   GotoLast:=true;
   ModalResult:=mrOK;
end;

procedure TDLGLocate.FindNextButtonClick(Sender: TObject);
begin
   FindNext := True;
   ModalResult := mrOK;
end;

end.

